from xkcd_python.xkcd import xkcd

Client = xkcd

__version__ = '2.9.0'
__author__ = "Sasen Perera"
__shot_des__ = "A python wrapper for xkcd.com"
__description__ = "A wrapper for xkcd.com's API. Built Using Python."